<?php

namespace Litecms\FaqCategory\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\FaqCategory\Models\FaqCategories;

class FaqCategoriesPolicy
{

    /**
     * Determine if the given user can view the faq_categories.
     *
     * @param UserPolicy $user
     * @param FaqCategories $faq_categories
     *
     * @return bool
     */
    public function view(UserPolicy $user, FaqCategories $faq_categories)
    {
        if ($user->canDo('faq_category.faq_categories.view') && $user->isAdmin()) {
            return true;
        }

        return $faq_categories->user_id == user_id() && $faq_categories->user_type == user_type();
    }

    /**
     * Determine if the given user can create a faq_categories.
     *
     * @param UserPolicy $user
     * @param FaqCategories $faq_categories
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('faq_category.faq_categories.create');
    }

    /**
     * Determine if the given user can update the given faq_categories.
     *
     * @param UserPolicy $user
     * @param FaqCategories $faq_categories
     *
     * @return bool
     */
    public function update(UserPolicy $user, FaqCategories $faq_categories)
    {
        if ($user->canDo('faq_category.faq_categories.edit') && $user->isAdmin()) {
            return true;
        }

        return $faq_categories->user_id == user_id() && $faq_categories->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given faq_categories.
     *
     * @param UserPolicy $user
     * @param FaqCategories $faq_categories
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, FaqCategories $faq_categories)
    {
        return $faq_categories->user_id == user_id() && $faq_categories->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given faq_categories.
     *
     * @param UserPolicy $user
     * @param FaqCategories $faq_categories
     *
     * @return bool
     */
    public function verify(UserPolicy $user, FaqCategories $faq_categories)
    {
        if ($user->canDo('faq_category.faq_categories.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given faq_categories.
     *
     * @param UserPolicy $user
     * @param FaqCategories $faq_categories
     *
     * @return bool
     */
    public function approve(UserPolicy $user, FaqCategories $faq_categories)
    {
        if ($user->canDo('faq_category.faq_categories.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
